function D = odct2dict(n,L)
%ODCT2DICT 2-D overcomplete DCT dictionary.
%  D = ODCT2DICT([N1 N2],[L1 L2]) returns an overcomplete DCT dictionary
%  for signals of size N1xN2. The number of dictionary atoms used to
%  represent the i-th signal dimension is Li, so the combined dictionary
%  has L1*L2 atoms.
%
%  D = ODCT2DICT([N1 N2],L) can be used to specify L - the total number of
%  atoms required in the dictionary, instead of L1 and L2 individually.
%  This call sets L1 and L2 automatically so that L1/L2 ~ N1/N2, by letting
%  L1=ceil(sqrt(L*N1/N2)) and L2=ceil(sqrt(L*N2/N1)). Note that the actual
%  number of atoms in the returned dictionary will be equal to or larger
%  than L.
%
%  D = ODCT2DICT(N,L) is shorthand to the call ODCT2DICT([N N],L) and
%  returns the overcomplete DCT dictionary for signals of size NxN. L is
%  the required size of the overcomplete dictionary, and is rounded up to
%  the nearest square integer.
%
%  See also ODCTDICT, ODCT3DICT, ODCTNDICT.

%  Ron Rubinstein
%  Computer Science Department
%  Technion, Haifa 32000 Israel
%  ronrubin@cs
%
%  February 2008

D = odctndict(n,L,2);
