function D = odct3dict(n,L)
%ODCT2DICT 3-D overcomplete DCT dictionary.
%  D = ODCT3DICT([N1 N2 N3],[L1 L2 L3]) returns an overcomplete DCT
%  dictionary for signals of size N1xN2xN3. The number of dictionary atoms
%  used to represent the i-th signal dimension is Li, so the combined
%  dictionary has L1*L2*L3 atoms.
%
%  D = ODCT3DICT([N1 N2 N3],L) can be used to specify L - the total number
%  of atoms required in the dictionary, instead of each of the Li's
%  individually. This call sets the Li's automatically so that their
%  relative sizes are roughly proportional to the Ni's. The actual number
%  of atoms in the returned dictionary is equal to or larger than L, as
%  integer rounding may be required to determine the Li's.
%
%  D = ODCT3DICT(N,L) is shorthand to the call ODCT2DICT([N N N],L) and
%  returns the overcomplete DCT dictionary for signals of size NxNxN. L is
%  the required size of the overcomplete dictionary, and is rounded up to
%  the nearest cubic integer.
%
%  See also ODCTDICT, ODCT2DICT, ODCTNDICT.

%  Ron Rubinstein
%  Computer Science Department
%  Technion, Haifa 32000 Israel
%  ronrubin@cs
%
%  February 2008

D = odctndict(n,L,3);
